@@ -6,12 +6,14 @@ from cloudlb.errors import InvalidProtocol, InvalidLoadBalancerName
 from cloudlb.node import Node, NodeDict
 from cloudlb.virtualip import VirtualIP
 from cloudlb.usage import get_usage
+from cloudlb.stats import Stats
 from cloudlb.accesslist import AccessList
 from cloudlb.healthmonitor import HealthMonitorManager
 from cloudlb.sessionpersistence import SessionPersistenceManager
 from cloudlb.connectionlogging import ConnectionLogging
 from cloudlb.connectionthrottle import ConnectionThrottleManager
-
+from cloudlb.errorpage import ErrorPage
+from cloudlb.ssltermination import SSLTermination
 
 class LoadBalancer(base.Resource):
     accessList = None
@@ -47,7 +49,8 @@ class LoadBalancer(base.Resource):
             setattr(self, k, v)
 
     def add_nodes(self, nodes):
-        self.manager.add_nodes(self.id, nodes)
+        resp, body = self.manager.add_nodes(self.id, nodes)
+        return [Node(parent=self, **x) for x in body['nodes']]
 
     def update(self):
         self.manager.update(self, self._info, self.__dict__)
@@ -59,6 +62,10 @@ class LoadBalancer(base.Resource):
                         startTime=startTime, endTime=endTime)
         return ret
 
+    def get_stats(self):
+        stats = Stats(self.manager.api.client, base.getid(self))
+        return stats.get() 
+
     def accesslist(self):
         accesslist = AccessList(self.manager.api.client, base.getid(self))
         return accesslist
@@ -72,6 +79,10 @@ class LoadBalancer(base.Resource):
             self.manager.api.client, base.getid(self))
         return sm
 
+    def errorpage(self):
+        errorpage = ErrorPage(self.manager.api.client, base.getid(self))
+        return errorpage
+
     def connection_logging(self):
         cm = ConnectionLogging(
             self.manager.api.client, base.getid(self))
@@ -84,6 +95,10 @@ class LoadBalancer(base.Resource):
         )
         return ctm
 
+    def ssl_termination(self):
+        sslt = SSLTermination(self.manager.api.client, base.getid(self))
+        return sslt
+
 
 class LoadBalancerManager(base.ManagerWithFind):
     resource_class = LoadBalancer
@@ -109,8 +124,19 @@ class LoadBalancerManager(base.ManagerWithFind):
                     self._list("/loadbalancers.json", "loadBalancers") \
                  if x._info['status'] != "DELETED"]
 
+    def search(self, ip):
+        """
+        Get a list of loadbalancers who are balancing traffic to `ip`.
+        The loadbalancer details are not as complete as the list() call,
+        only name, status and id are returned.
+        """
+        return [x for x in \
+                    self._list("/loadbalancers.json?nodeaddress=%s" % ip, 
+                        "loadBalancers")]
+        
+
     def create(self, name, port,
-               protocol, nodes, virtualIps):
+               protocol, nodes, virtualIps, algorithm='RANDOM'):
         """
         Create a new loadbalancer.
 
@@ -133,6 +159,7 @@ class LoadBalancerManager(base.ManagerWithFind):
             "protocol": protocol,
             "nodes": nodeDico,
             "virtualIps": vipDico,
+            "algorithm": algorithm,
             }}
 
         return self._create("/loadbalancers", body, "loadBalancer")
@@ -146,10 +173,12 @@ class LoadBalancerManager(base.ManagerWithFind):
         """
         self._delete("/loadbalancers/%s" % base.getid(loadbalancerid))
 
-    def add_nodes(self, loadbalancerId, nodes):
+    def add_nodes(self, loadBalancerId, nodes):
         nodeDico = [x.toDict() for x in nodes]
-        self._action('nodes', "%d/nodes" % base.getid(loadbalancerId), \
-                         nodeDico)
+        resp, body = self.api.client.post('/loadbalancers/%d/nodes' % (
+                            base.getid(loadBalancerId)
+                            ), body={"nodes": nodeDico})
+        return (resp, body)
 
     def delete_node(self, loadBalancerId, nodeId):
         self.api.client.delete('/loadbalancers/%d/nodes/%d' % (
@@ -179,8 +208,3 @@ class LoadBalancerManager(base.ManagerWithFind):
 
         self.api.client.put('/loadbalancers/%s' % base.getid(lb), body=ret)
 
-    def _action(self, action, url, info=None):
-        """
-        Perform a loadbalancer POST "action".
-        """
-        self.api.client.post('/loadbalancers/%s' % url, body={action: info})
